==> shardingsphere-infra-common-5.1.0-sources.jar: org/apache/shardingsphere/infra/distsql/update/RuleDefinitionDropUpdater.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.infra.distsql.update;

import org.apache.shardingsphere.infra.config.RuleConfiguration;
import org.apache.shardingsphere.sql.parser.sql.common.statement.SQLStatement;

/**
 * Drop rule rule definition updater.
 * 
 * @param <T> type of SQL statement
 * @param <R> type of rule configuration
 */
public interface RuleDefinitionDropUpdater<T extends SQLStatement, R extends RuleConfiguration> extends RuleDefinitionUpdater<T, R> {
    
    /**
     * Update current rule configuration.
     *
     * @param sqlStatement SQL statement
     * @param currentRuleConfig current rule configuration to be updated
     * @return current rule configuration is empty or not 
     */
    boolean updateCurrentRuleConfiguration(T sqlStatement, R currentRuleConfig);
}

==> shardingsphere-infra-common-5.1.1-sources.jar: org/apache/shardingsphere/infra/distsql/update/RuleDefinitionDropUpdater.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.infra.distsql.update;

import org.apache.shardingsphere.infra.config.RuleConfiguration;
import org.apache.shardingsphere.sql.parser.sql.common.statement.SQLStatement;

import java.util.Collection;
import java.util.stream.Collectors;

/**
 * Drop rule definition updater.
 * 
 * @param <T> type of SQL statement
 * @param <R> type of rule configuration
 */
public interface RuleDefinitionDropUpdater<T extends SQLStatement, R extends RuleConfiguration> extends RuleDefinitionUpdater<T, R> {
    
    /**
     * Update current rule configuration.
     *
     * @param sqlStatement SQL statement
     * @param currentRuleConfig current rule configuration to be updated
     * @return current rule configuration is empty or not
     */
    boolean updateCurrentRuleConfiguration(T sqlStatement, R currentRuleConfig);
    
    /**
     * Whether there is configuration.
     *
     * @param currentRuleConfig current rule configuration 
     * @return configuration exists or does not exist
     */
    default boolean isExistRuleConfig(R currentRuleConfig) {
        return currentRuleConfig != null;
    }
    
    /**
     * Whether there is dropped data.
     * 
     * @param sqlStatement SQL statement
     * @param currentRuleConfig current rule configuration
     * @return dropped data exists or does not exist
     */
    default boolean hasAnyOneToBeDropped(T sqlStatement, R currentRuleConfig) {
        return true;
    }
    
    /**
     * Get identical data.
     *
     * @param currentRules collection
     * @param toBeDroppedRules collection
     * @return identical data
     */
    default Collection<String> getIdenticalData(Collection<String> currentRules, Collection<String> toBeDroppedRules) {
        return currentRules.stream().filter(toBeDroppedRules::contains).collect(Collectors.toSet());
    }
}
